#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_ANDNOT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_ANDNOT_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/bitwise_andnot.hpp>

#endif
